summaryrefslogtreecommitdiff
path: root/pango/pango-layout-private.h
diff options
context:
space:
mode:
Diffstat (limited to 'pango/pango-layout-private.h')
-rw-r--r--pango/pango-layout-private.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/pango/pango-layout-private.h b/pango/pango-layout-private.h
index 1805e730..b9f9b137 100644
--- a/pango/pango-layout-private.h
+++ b/pango/pango-layout-private.h
@@ -112,11 +112,12 @@ struct _PangoLayoutIter
Extents *line_extents;
int line_index;
- /* X position of the current run */
+ /* Position of the current run */
int run_x;
/* Width of the current run */
int run_width;
+ int end_x_offset;
/* this run is left-to-right */
gboolean ltr;
@@ -112,11 +112,12 @@ struct _PangoLayoutIter
int run_x;
- /* Width of the current run */
+ /* Width and end offset of the current run */
int run_width;